.. _AUTHORS:

Contributors
============

Development
~~~~~~~~~~~

The following have contributed by writing and/or designing the code base of Pharmpy.

Current team
------------

* Rikard Nordgren, rikard.nordgren@farmaci.uu.se (maintainer)
* Stella Belin, stella.belin@farmaci.uu.se (maintainer)
* Johan Borg
* Antonia Hufnagl

All developers past and present
-------------------------------

* Rikard Nordgren
* Stella Belin
* Kajsa Harling
* Zhe Huang
* Aurelien Ooms
* Gunnar Yngman
* Johan Borg
* Antonia Hufnagl
* Viktor Rognås

Scientific input
~~~~~~~~~~~~~~~~

* Mats O. Karlsson
* Andrew C. Hooker
* João A. Abrantes
* Piyanan Assawasuwannakit
* Simon Buatois
* Simon Carter
* Xiaomei Chen
* Alzahra Hamdan
* Osama Qutishat
* Sebastian Ueckert
* Shijun Wang
* Tianwu Yang
* Keqi Shi
* Xuanlin Liu
* Samia Mohamed
* Yersultan Mirasbekov

Funding
~~~~~~~

A warm thanks to all our sponsors!

*  F\. Hoffman-La Roche Ltd.
*  Pharmetheus
*  Uppsala University

Part of the computations needed for testing of Pharmpy was enabled by resources provided by the Swedish National Infrastructure for Computing (SNIC) at UPPMAX, partially funded by the Swedish Research Council.
